pub struct JwtAuth<T> { /* private fields */ }Expand description
Validates HS256 bearer tokens and exposes their typed claims to handlers.
A previous secret can be accepted during key rotation. Token headers are constrained to HS256 before signature verification to prevent algorithm-confusion attacks.
Implementations
Sourceimpl<T> JwtAuth<T>where
T: Clone + DeserializeOwned + 'static,
impl<T> JwtAuth<T>where
T: Clone + DeserializeOwned + 'static,
pub fn new(secret: impl AsRef<[u8]>) -> Self
pub fn with_previous_secret(self, secret: impl AsRef<[u8]>) -> Self
pub fn with_leeway(self, seconds: u64) -> Self
pub fn with_claim_projection(self, projection: JwtClaimProjection) -> Self
pub fn claims(request: &HttpRequest) -> Option<T>
pub fn projected_claims( request: &HttpRequest, ) -> Option<BTreeMap<String, Value>>