pub struct ValidatedRequest<P, Q, H, B> {
pub path: P,
pub query: Q,
pub headers: H,
pub body: B,
}Expand description
A request parsed and validated from its path, query, headers, and JSON body.
This extractor keeps each transport source in a separate application type, avoiding ambiguous precedence when the same field name appears in more than one source.
Fields
path: Pquery: Qheaders: Hbody: BTrait Implementations
Sourceimpl<P, Q, H, B> FromRequest for ValidatedRequest<P, Q, H, B>where
P: DeserializeOwned + Validate + 'static,
Q: DeserializeOwned + Validate + 'static,
H: FromRequestHeaders + Validate + 'static,
B: DeserializeOwned + Validate + 'static,
impl<P, Q, H, B> FromRequest for ValidatedRequest<P, Q, H, B>where
P: DeserializeOwned + Validate + 'static,
Q: DeserializeOwned + Validate + 'static,
H: FromRequestHeaders + Validate + 'static,
B: DeserializeOwned + Validate + 'static,
Sourcetype Future = Pin<Box<dyn Future<Output = Result<ValidatedRequest<P, Q, H, B>, <ValidatedRequest<P, Q, H, B> as FromRequest>::Error>>>>
type Future = Pin<Box<dyn Future<Output = Result<ValidatedRequest<P, Q, H, B>, <ValidatedRequest<P, Q, H, B> as FromRequest>::Error>>>>
Future that resolves to a
Self. Read moreSourcefn from_request(request: &HttpRequest, payload: &mut Payload) -> Self::Future
fn from_request(request: &HttpRequest, payload: &mut Payload) -> Self::Future
Create a
Self from request parts asynchronously.Auto Trait Implementations
impl<P, Q, H, B> Freeze for ValidatedRequest<P, Q, H, B>
impl<P, Q, H, B> RefUnwindSafe for ValidatedRequest<P, Q, H, B>
impl<P, Q, H, B> Send for ValidatedRequest<P, Q, H, B>
impl<P, Q, H, B> Sync for ValidatedRequest<P, Q, H, B>
impl<P, Q, H, B> Unpin for ValidatedRequest<P, Q, H, B>
impl<P, Q, H, B> UnsafeUnpin for ValidatedRequest<P, Q, H, B>
impl<P, Q, H, B> UnwindSafe for ValidatedRequest<P, Q, H, B>