pub struct PermitBody<B> { /* private fields */ }Trait Implementations
Sourceimpl<B: MessageBody> MessageBody for PermitBody<B>
impl<B: MessageBody> MessageBody for PermitBody<B>
Sourcetype Error = <B as MessageBody>::Error
type Error = <B as MessageBody>::Error
The type of error that will be returned if streaming body fails. Read more
Sourcefn poll_next(
self: Pin<&mut Self>,
context: &mut Context<'_>,
) -> Poll<Option<Result<Bytes, Self::Error>>>
fn poll_next( self: Pin<&mut Self>, context: &mut Context<'_>, ) -> Poll<Option<Result<Bytes, Self::Error>>>
Attempt to pull out the next chunk of body bytes. Read more