pub struct RequestBodyLimit { /* private fields */ }Expand description
Buffers request bodies, optionally expands gzip input, and rejects oversized payloads.
Both compressed and expanded data are checked, preventing a small gzip payload from expanding beyond the configured application limit.
Implementations