Module route

Module route 

Structs

RouteGroupConfig
A route group with a shared prefix and inheritable policy defaults.
RouteJwtConfig
HS256 authentication inherited by every route in a declarative group unless a route is public.
RouteMiddlewareNext
The remainder of a declarative route’s middleware and handler chain.
RoutePolicyConfig
Policy overrides for one method and route pattern.

Traits

RouteMiddleware
Type-erased application middleware that can be registered by name on crate::RestServer.

Type Aliases

RouteMiddlewareFuture
The boxed future returned by application-defined route middleware.