pub struct RouteGroupConfig {
pub prefix: String,
pub jwt: Option<RouteJwtConfig>,
pub timeout_ms: Option<u64>,
pub max_body_bytes: Option<usize>,
pub priority: bool,
pub sse: bool,
pub middleware: Vec<String>,
pub routes: Vec<RoutePolicyConfig>,
}Expand description
A route group with a shared prefix and inheritable policy defaults.
Fields
prefix: Stringjwt: Option<RouteJwtConfig>timeout_ms: Option<u64>max_body_bytes: Option<usize>priority: boolsse: boolmiddleware: Vec<String>Named application middleware, applied in declaration order around every route in the group.
routes: Vec<RoutePolicyConfig>Trait Implementations
Sourceimpl Clone for RouteGroupConfig
impl Clone for RouteGroupConfig
Sourcefn clone(&self) -> RouteGroupConfig
fn clone(&self) -> RouteGroupConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RouteGroupConfig
impl Debug for RouteGroupConfig
Sourceimpl Default for RouteGroupConfig
impl Default for RouteGroupConfig
Sourcefn default() -> RouteGroupConfig
fn default() -> RouteGroupConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RouteGroupConfig
impl<'de> Deserialize<'de> for RouteGroupConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RouteGroupConfig
Sourceimpl PartialEq for RouteGroupConfig
impl PartialEq for RouteGroupConfig
Sourceimpl Serialize for RouteGroupConfig
impl Serialize for RouteGroupConfig
impl StructuralPartialEq for RouteGroupConfig