Structs
- Route
Group Config - A route group with a shared prefix and inheritable policy defaults.
- Route
JwtConfig - HS256 authentication inherited by every route in a declarative group unless a route is public.
- Route
Middleware Next - The remainder of a declarative route’s middleware and handler chain.
- Route
Policy Config - Policy overrides for one method and route pattern.
Traits
- Route
Middleware - Type-erased application middleware that can be registered by name on
crate::RestServer.
Type Aliases
- Route
Middleware Future - The boxed future returned by application-defined route middleware.